CONTRACT_ADDRESS = {
    # Arbitrum Sepolia
    421614: {
        "peripherals": {
            "vault": "0x6e664f5025ee54704040a970d2bfa1ecbbc20fd4"
        }
    },
    # Base Mainnet
    8453: {
        "peripherals": {
            "vault": "0x764ab030159466edf9663e3fe3198c5d5c26c122"
        }
    },

}

VAULT_CONTRACT_ABI = "abis/vault.json"
ERC20_ABI_PATH = "abis/erc20.json"
